An implementation of the Splicebuster algorithm
=======

# Description


Analyze an image for forgeries with the Splicebuster algorithm.
# Usage:


```bash
usage: argmark [-h] [-o OUT] [--quantization QUANTIZATION] [--symmetry | --no-symmetry] [--complementary | --no-complementary] [--sqrt | --no-sqrt] [--hist-pooling {full,half,none}] [--block-size BLOCK_SIZE]
               [--stride-divider STRIDE_DIVIDER] [--max-saturated MAX_SATURATED] [--normalize-correct | --normalize-original] [--pca PCA]
               [--box SUPERVISION SUPERVISION SUPERVISION SUPERVISION | --mask SUPERVISION | --gm | --gum | --direct] [--n-init N_INIT] [--max-iter MAX_ITER] [--tolerance TOLERANCE] [--logalpha LOGALPHA]
               [--p-outlier-init P_OUTLIER_INIT] [--noise NOISE] [--gray] [--gamma GAMMA] [--jpeg JPEG] [--median]
               input

```
# Arguments

|short|long|default|help|
| :--- | :--- | :--- | :--- |
|`-h`|`--help`||show this help message and exit|
|`-o`|`--out`|`out`|Path to store the outputs. Images will be saved as PATH_*.png.|
||`--quantization`|`6`|Size of the center bin during quantization. Default: 6|
||`--symmetry`||Map symmetric entries (eg (a, b, c, d) and (d, c, b, a)) to the same value.|
||`--no-symmetry`||Do not reduce the co-occurence matrix by symmetries.|
||`--complementary`||Complementary-to-2 entries (eg (a, b, c, d) and (2-a, 2-b, 2-c, 2-d)) will be mapped to the same value|
||`--no-complementary`||Do not reduce the co-occurence matrix by complementaries.|
||`--sqrt`||Use the square root of the histograms.|
||`--no-sqrt`||Do not perform square rooting of the histograms.|
||`--hist-pooling`|`half`|How to pool the histograms. `full`: All four histograms are added together, `half`: dual histograms are added, the two remaining groups are concatenated. `none`: the four histograms are concatenated.|
||`--block-size`|`128`|Block size for the moving window average|
||`--stride-divider`|`16`|Stride is the ratio of the block size by this number|
||`--max-saturated`|`0.15`|Maximum ratio of saturated pixels for a window to be considered valid.|
||`--normalize-correct`|`correct`|Use the correct normalization for the histograms.|
||`--normalize-original`|`correct`|Normalize the histograms according to the original article.|
||`--pca`|`5`|Number of components for principal components analysis. Use 0 to keep all components.|
||`--box`|`direct`|Bounding box of a suspicious region for supervised detection: X_start Y_start Width Height|
||`--mask`|`direct`|Path to the mask of a suspicious region for supervised detection|
||`--gm`|`direct`|Unsupervised detection with a Gaussian-Gaussian Mixture|
||`--gum`|`direct`|Unsupervised detection with a Gaussian-Uniform Mixture|
||`--direct`|`direct`|Unsupervised detection with direct estimation of the model|
||`--n-init`|`5`|Number of initializations to use (the best result will be kept)|
||`--max-iter`|`100`|Maximum number of iterations for each EM initialization|
||`--tolerance`|`1e-05`|Tolerence criterion for convergence|
||`--logalpha`|`42`|Log outlier threshold|
||`--p-outlier-init`|`0.01`|Initial probability of outlier|
||`--noise`|`None`|Add AWGN of the specified std (as degrees of 255) to the image|
||`--gray`||Added AWGN will be gray. Has no effect if --noise is not provided.|
||`--gamma`|`None`|Gamma correction factor|
||`--jpeg`|`None`|JPEG compression with the given factor|
||`--median`||Median filtering|



# Outputs
Assuming the output path is `out`, this program will save the following figures:
|Filename|Description|
| :--- | :--- |
|`out_input.png`|Input image, after optionnal post-processing|
|`out_mahal_valid.png`|Mahalanobis distance on valid features|
|`out_mahal_weighted.png`|Mahalanobis distance on all non-fully saturated features, computed on non-saturated regions of those features (will probably be removed)|
|`out_mahal_full.png`|Mahalanobis distance on all features, computed without saturation weights.|
|`out_normalized_distance.png`|Mahalanobis distance, normalised to `[0, 1]` with the highest value being set to 1, as used in the original paper.|
|`out_mask_valid.png`|Regions detected as saturated, and excluded from the training and detection.|
|`out_mask_training.png`|Training mask: excludes both saturated regions and zones provided as suspicious in supervised mode.|
